from time import sleep

from google.auth.transport import requests
import requests as req
import os

from google.cloud import compute
from google.oauth2 import service_account
from googleapiclient import discovery

from deploy.domain.file_path import FilePath


class GoogleCloud:
    json_config_file: str = f"{FilePath().get_path(__file__)}/../config_files/gcloud_config.json"

    def __init__(self, project: str, zone: str, vm_name: str):

        self.project: str = project
        self.zone: str = zone
        self.region: str = zone[:-2]
        self.vm_name = vm_name

    @classmethod
    def get_token(cls) -> str:

        if not os.path.isfile(cls.json_config_file):
            raise FileNotFoundError("ERROR: File Not found.")

        else:
            credentials = service_account.Credentials.from_service_account_file(cls.json_config_file, scopes=[
                'https://www.googleapis.com/auth/cloud-platform'])

            try:
                credentials.refresh(requests.Request())
                access_token = credentials.token
                return access_token

            except Exception as e:
                return f"Error: {e}"

    def get_info(self) -> dict:

        url = f'https://compute.googleapis.com/compute/v1/projects/{self.project}/zones/{self.zone}/instances/{self.vm_name}'

        response = req.request("GET", url, headers=self.headers)
        print(response.json())
        return response.json()

    def get_public_ip(self) -> str:
        response = self.get_info()
        print(response['networkInterfaces'][0]['accessConfigs'][0]['natIP'])
        return response['networkInterfaces'][0]['accessConfigs'][0]['natIP']

    def get_private_ip(self) -> str:
        response = self.get_info()
        print(response['networkInterfaces'][0]['networkIP'])
        return response['networkInterfaces'][0]['networkIP']

    def get_zone_info(self):
        url = f'https://compute.googleapis.com/compute/v1/projects/{self.project}'

        response = req.request("GET", url, headers=self.headers)
        print(response.json())
        return response.json()

    def get_subnetwork(self):
        url = f'https://compute.googleapis.com/compute/v1/projects/{self.project}/regions/{self.region}/subnetworks/default'

        response = req.request("GET", url, headers=self.headers)
        print(response.json()["ipCidrRange"])
        return response.json()["ipCidrRange"]

    @property
    def headers(self):
        return {
            'Accept': 'application/json',
            'Authorization': f"Bearer {self.get_token()}"
        }

    def reboot(self):
        url = f"https://compute.googleapis.com/compute/v1/projects/{self.project}/zones/{self.zone}/instances/{self.vm_name}/reset"
        response = req.request("POST", url, headers=self.headers)
        if response.status_code == 200:
            print(f"VM {self.vm_name} rebooting....")
            sleep(60)
            if (os.system("ping -c 4 " + self.get_public_ip())) == 0:
                print(f"SERVER {self.vm_name} UP!!")
            else:
                print(f"ERROR: SERVER {self.vm_name} IS DOWN!!!")

