from enum import Enum
from pydantic import BaseModel
from typing import List, Union, Optional


class AccessItemDestinationType(Enum):
    HOST_SERVICE = "HOST_SERVICE"
    NETWORK_SERVICE = "NETWORK_SERVICE"
    PUBLISHED_SERVICE = "PUBLISHED_SERVICE"
    USER_GROUP = "USER_GROUP"


class AccessItemSourceType(Enum):
    HOST = "HOST"
    NETWORK_SERVICE = "NETWORK_SERVICE"
    USER_GROUP = "USER_GROUP"


class ServiceProtocol(Enum):
    ICMP = "ICMP"
    TCP = "TCP"
    UDP = "UDP"


class InternetAccessType(str, Enum):
    BLOCKED = "BLOCKED"
    GLOBAL_INTERNET = "GLOBAL_INTERNET"
    LOCAL = "LOCAL"


class NetworkItemType(Enum):
    HOST = "HOST"
    NETWORK = "NETWORK"


class IpRouteType(Enum):
    IP_V4 = "IP_V4"
    IP_V6 = "IP_V6"


class SessionStatus(Enum):
    OFFLINE = "OFFLINE"
    ONLINE = "ONLINE"
    ONLINE_WITH_ISSUES = "ONLINE_WITH_ISSUES"


class UserGroupConnectAuth(Enum):
    AUTH = "AUTH"
    AUTO = "AUTO"
    STRICT_AUTH = "STRICT_AUTH"


class UserRole(Enum):
    ADMIN = "ADMIN"
    MEMBER = "MEMBER"
    OWNER = "OWNER"


class UserStatus(Enum):
    ACTIVE = "ACTIVE"
    CANCELED = "CANCELED"
    INVITED = "INVITED"
    SUSPENDED = "SUSPENDED"
    SUSPENDED_IDP = "SUSPENDED_IDP"


class AccessSimpleItemResponse(BaseModel):
    id: str
    name: str


class AccessItemDestinationResponse(BaseModel):
    allCovered: bool
    children: List[AccessSimpleItemResponse]
    parent: AccessSimpleItemResponse
    type: AccessItemDestinationType


class AccessItemSourceResponse(BaseModel):
    allCovered: bool
    children: List[AccessSimpleItemResponse]
    parent: AccessSimpleItemResponse
    type: AccessItemSourceType


class AccessGroupResponse(BaseModel):
    defaultGroup: bool
    description: str
    destination: List[AccessItemDestinationResponse]
    id: str
    name: str
    source: List[AccessItemSourceResponse]


class ServiceConfigRequest(BaseModel):
    customServiceTypes: Optional[list[str]]
    serviceTypes: List[str]


class ServiceConfigResponse(ServiceConfigRequest):
    pass


class ServiceRequest(BaseModel):
    config: ServiceConfigRequest
    description: str
    name: str
    routes: List['RouteRequest']
    type: str


class ServiceResponse(BaseModel):
    config: ServiceConfigResponse
    description: str
    id: str
    name: str
    networkItemId: str
    networkItemType: NetworkItemType
    routes: List['RouteResponse']
    type: str


class PageOfDnsRecordResponse(BaseModel):
    content: List['DnsRecordResponse']
    numberOfElements: int
    page: int
    size: int
    success: bool
    totalElements: int
    totalPages: int


class PageOfUserGroupResponse(BaseModel):
    content: List['UserGroupResponse']
    numberOfElements: int
    page: int
    size: int
    success: bool
    totalElements: int
    totalPages: int


class PageOfUserResponse(BaseModel):
    content: List['UserStatusResponse']
    numberOfElements: int
    page: int
    size: int
    success: bool
    totalElements: int
    totalPages: int


class RangeInt(BaseModel):
    lowerValue: int
    upperValue: int


class RouteRequest(BaseModel):
    allowEmbeddedIp: bool
    description: str
    value: str


class RouteResponse(RouteRequest):
    domain: str
    id: str
    parentRouteId: str
    subnet: str
    type: Union[IpRouteType, NetworkItemType]


class UserCreateRequest(BaseModel):
    devices: List['DeviceCreateRequest']
    email: str
    firstName: str
    groupId: str
    lastName: str
    role: UserRole
    username: str


class UserGroupRequest(BaseModel):
    allRegionsIncluded: bool
    connectAuth: UserGroupConnectAuth
    id: str
    internetAccess: InternetAccessType
    maxDevice: int
    name: str
    vpnRegionIds: List[str]


class UserGroupResponse(BaseModel):
    connectAuth: UserGroupConnectAuth
    id: str
    internetAccess: InternetAccessType
    maxDevice: int
    name: str
    systemSubnets: List[str]
    vpnRegionIds: List[str]


class UserResponse(BaseModel):
    authType: str
    devices: List['DeviceResponse']
    email: str
    firstName: str
    groupId: str
    id: str
    lastName: str
    role: UserRole
    status: UserStatus
    username: str


class UserStatusResponse(BaseModel):
    authType: str
    connectionStatus: SessionStatus
    devices: List['DeviceStatusResponse']
    email: str
    firstName: str
    groupId: str
    id: str
    lastName: str
    role: UserRole
    status: UserStatus
    username: str


class VpnRegionResponse(BaseModel):
    continent: str
    country: str
    countryIso: str
    id: str
    regionName: str


class AccessItemDestinationRequest(BaseModel):
    allCovered: bool
    children: List[str]
    parent: str
    type: AccessItemDestinationType


class AccessItemSourceRequest(BaseModel):
    allCovered: bool
    children: List[str]
    parent: str
    type: AccessItemSourceType


class AccessGroupRequest(BaseModel):
    description: str
    destination: List[AccessItemDestinationRequest]
    name: str
    source: List[AccessItemSourceRequest]


class IpRouteResponse(BaseModel):
    description: str
    id: str
    subnet: str
    type: IpRouteType


class ApplicationResponse(BaseModel):
    config: ServiceConfigResponse
    description: str
    id: str
    name: str
    networkItemId: str
    networkItemType: NetworkItemType
    routes: List[IpRouteResponse]
    type: str


class ConnectorRequest(BaseModel):
    description: str
    name: str
    vpnRegionId: str


class ConnectorResponse(BaseModel):
    description: str
    id: str
    ipV4Address: str
    ipV6Address: str
    name: str
    networkItemId: str
    networkItemType: NetworkItemType
    vpnRegionId: str


class ConnectorStatusResponse(BaseModel):
    connectionStatus: SessionStatus
    description: str
    id: str
    ipV4Address: str
    ipV6Address: str
    name: str
    networkItemId: str
    networkItemType: NetworkItemType
    vpnRegionId: str


class FailedUserCreateResponse(BaseModel):
    errors: dict
    request: UserCreateRequest


class CreateUsersResponse(BaseModel):
    completed: bool
    failed: List[FailedUserCreateResponse]
    succeed: List[UserResponse]


class CustomServiceTypeRequest(BaseModel):
    icmpType: List[RangeInt]
    port: List[RangeInt]
    protocol: ServiceProtocol


class CustomServiceTypeResponse(BaseModel):
    icmpType: List[RangeInt]
    port: List[RangeInt]
    protocol: ServiceProtocol


class DeviceCreateRequest(BaseModel):
    description: str
    name: str


class DeviceResponse(BaseModel):
    description: str
    id: str
    ipV4Address: str
    ipV6Address: str
    name: str
    vpnRegions: List[VpnRegionResponse]


class DeviceStatusResponse(BaseModel):
    connectionStatus: SessionStatus
    description: str
    id: str
    ipV4Address: str
    ipV6Address: str
    name: str
    vpnRegions: List[VpnRegionResponse]


class DnsRecordRequest(BaseModel):
    description: str
    domain: str
    ipv4Addresses: List[str]
    ipv6Addresses: List[str]


class DnsRecordResponse(BaseModel):
    description: str
    domain: str
    id: str
    ipv4Addresses: List[str]
    ipv6Addresses: List[str]


class DomainRouteResponse(BaseModel):
    allowEmbeddedIp: bool
    description: str
    domain: str
    id: str
    type: NetworkItemType


class ErrorDetails(BaseModel):
    errorCode: str
    message: str
    params: dict


class HostCreateRequest(BaseModel):
    connectors: List[ConnectorRequest]
    description: str
    domain: str
    internetAccess: InternetAccessType
    name: str


class HostResponse(BaseModel):
    connectors: List[ConnectorResponse]
    description: str
    domain: str
    id: str
    internetAccess: InternetAccessType
    name: str
    systemSubnets: List[str]


class HostUpdateRequest(BaseModel):
    description: str
    destinationListsIds: List[str]
    domain: str
    gatewaysIds: List[str]
    internetAccess: InternetAccessType
    name: str


class IpServiceResponse(ApplicationResponse):
    pass


class NetworkCreateRequest(BaseModel):
    connectors: List[ConnectorRequest]
    description: str
    egress: bool
    internetAccess: InternetAccessType
    name: str
    routes: List[RouteRequest]


class NetworkResponse(BaseModel):
    connectors: List[ConnectorResponse]
    description: str
    egress: bool
    id: str
    internetAccess: InternetAccessType
    name: str
    routes: List[IpRouteResponse]
    systemSubnets: List[str]


class NetworkUpdateRequest(BaseModel):
    description: str
    destinationListsIds: List[str]
    egress: bool
    gatewaysIds: List[str]
    internetAccess: InternetAccessType
    name: str


class OAuthResponse(BaseModel):
    access_token: str
    expires_in: int
    scope: str
    token_type: str


class SessionResponse(BaseModel):
    bytesIn: int
    bytesOut: int
    clientUUID: str
    connectorId: str
    connectorName: str
    deviceId: str
    deviceName: str
    disconnectReason: str
    email: str
    firstName: str
    hostId: str
    hostName: str
    id: str
    lastName: str
    networkId: str
    networkName: str
    osType: str
    osVersion: str
    protocol: str
    publicIp: str
    region: str
    sessionDurationSeconds: int
    sessionEndTime: str
    sessionStartTime: str
    status: SessionStatus
    tunnelIpV4: str
    tunnelIpV6: str
    userGroup: str
    userId: str
    userName: str


class PageOfSessionsResponse(BaseModel):
    nextCursor: str
    sessions: List[SessionResponse]


class SessionsResponse(BaseModel):
    nextCursor: str
    sessions: List[SessionResponse]
