from pydantic import BaseModel

from deploy.domain.models.user_models import NewUser


class Tenant(BaseModel):
    name: str
    address: str | None = ""
    phone: str | None = ""

    class Config:
        json_schema_extra = {
            "example": {
                "name": "Company Name",
                "address": "John Doe Str. 122",
                "phone": "+1 123 456 78",
            }
        }


class NewTenant(Tenant):
    user: NewUser


class ExistingTenant(BaseModel):
    address: str | None = ""
    phone: str | None = ""

    class Config:
        json_schema_extra = {
            "example": {
                "address": "John Doe Str. 122",
                "phone": "+1 123 456 78",
            }
        }


class ClientNetworkConfigParameters(BaseModel):
    ip_cidr: str
    gateway: str
    allowed_networks: list[str]


class TenantCloudConnexa(NewTenant):
    network_config: ClientNetworkConfigParameters
