from pydantic import BaseModel, EmailStr

from deploy.domain.role import Role


class User(BaseModel):
    username: str
    email: EmailStr
    name: str | None = ""
    surname: str | None = ""
    role: str = "admin"


class NewUser(User):
    password: str


class OwnUser(BaseModel):
    email: EmailStr | None = ""
    password: str | None = ""
    name: str | None = ""
    surname: str | None = ""


class ExistingUser(User):
    username: str | None = ""
    email: EmailStr | None = ""
    password: str | None = ""
    name: str | None = ""
    surname: str | None = ""
    role: Role | None = ""


class UpdatingUser(User):
    username: str
    email: EmailStr | None = ""
    password: str | None = ""
    name: str | None = ""
    surname: str | None = ""
    role: Role | None = ""


class DeleteUserResponse(BaseModel):
    message: str


class Users(BaseModel):
    users: list[User]

    class Config:
        json_schema_extra = {
            "example": {
                "users": [
                    {
                        "username": "user1",
                        "email": "user1@mymail.com",
                        "name": "user",
                        "surname": "one",
                        "role": "admin"
                    },
                    {
                        "username": "user2",
                        "email": "user2@mymail.com",
                        "name": "user",
                        "surname": "two",
                        "role": "editor"
                    },
                    {
                        "username": "user3",
                        "email": "user3@mymail.com",
                        "name": "user",
                        "surname": "three",
                        "role": "viewer"
                    }
                ]
            }
        }
