import asyncio
import threading
from fastapi import APIRouter
from fastapi import BackgroundTasks
from deploy.application.usecases.create_tenant import CreateTenant
from deploy.domain.network_connector_type import NetworkConnectorType
from deploy.domain.repository_type import RepositoryType
from deploy.domain.models.tenant_models import TenantCloudConnexa
from deploy.infraestructure.adapters.network_connectors.network_connector_factory import NetworkConnectorFactory
from deploy.infraestructure.adapters.repositories.atlas_mongo_db_create_tenant_repository_factory import \
    CreateTenantRepositoryFactory
from deploy.infraestructure.gateways.create_tenant_repository_interface import ICreateTenantRepository
from deploy.infraestructure.gateways.network_connector_interface import INetworkConnector

deploy_router = APIRouter(prefix="/api/v1/deploy", responses={404: {"message": "NOT FOUND"}}, tags=["deploy"])

repository_type: ICreateTenantRepository = CreateTenantRepositoryFactory.get_repository(
    RepositoryType.mongo_db_create_tenant)
network_connector: INetworkConnector = NetworkConnectorFactory.get_network_connector(NetworkConnectorType.cconnexa_vm)

lock = threading.Lock()


@deploy_router.post("/vmconnector/", status_code=201)
async def deploy(tenant: TenantCloudConnexa, background_tasks: BackgroundTasks) -> dict:
    background_tasks.add_task(async_process_tenant, tenant)
    return {
        "status": "WIP",
        "service_type": "VM connector",
        "message": f"Service provisioning In Progress... You will receive an email in {tenant.user.email} with instructions in a few minutes"
    }


async def async_process_tenant(tenant):
    loop = asyncio.get_event_loop()
    result = await loop.run_in_executor(None, process_tenant, tenant)
    return result


def process_tenant(tenant):
    lock.acquire()
    create_tenant = CreateTenant(repository_type, network_connector)
    response = create_tenant.create(tenant)
    lock.release()
    return response
