import json
from time import sleep

import requests as req
import yaml

from deploy.domain.file_path import FilePath
from deploy.domain.google_cloud import GoogleCloud
from deploy.domain.google_cloud_ssh import GoogleCloudSSH
from deploy.infraestructure.gateways.deploy_tenant_to_platform_interface import IDeployTenantToPlatform


class GoogleCloudVM(IDeployTenantToPlatform):

    def __init__(self):
        self.google_cloud = None
        self.ssh = None

        self.json_vm_template_path: str = f"{FilePath.get_path(__file__)}/../../../config_files/vm_template.json"
        self.json_gcloud_ssh_config_path: str = f"{FilePath.get_path(__file__)}/../../../config_files/gcloud_ssh_config.json"
        self.json_github_config_path: str = f"{FilePath.get_path(__file__)}/../../../config_files/github_config.json"

        self.json_vm_template = self.load_config_file(self.json_vm_template_path)
        self.json_gcloud_ssh_config = self.load_config_file(self.json_gcloud_ssh_config_path)
        self.json_github_config = self.load_config_file(self.json_github_config_path)

        self.url = f"https://www.googleapis.com/compute/v1/projects/networkmanager-397512/zones/europe-west4-a/instances"
        self.headers = {
            'Accept': 'application/json',
            'Authorization': f"Bearer {GoogleCloud.get_token()}"
        }

    def deploy(self, server_name: str) -> dict:
        self.json_vm_template["disks"][0]["deviceName"] = server_name
        self.json_vm_template["name"] = server_name
        machine_type_endpoint: str = self.json_vm_template["machineType"]
        self.google_cloud: GoogleCloud = GoogleCloud(vm_name=server_name,
                                                     project=machine_type_endpoint.split("/")[1],
                                                     zone=machine_type_endpoint.split("/")[3])
        self.google_cloud.vm_name = server_name
        response_create_vm = req.request("POST", self.url, headers=self.headers, json=self.json_vm_template)
        sleep(90)
        print(f"PUBLIC TENANT IP: {self.google_cloud.get_public_ip()}")

        self.ssh: GoogleCloudSSH = GoogleCloudSSH(hostname=self.google_cloud.get_public_ip(),
                                                  username=self.json_gcloud_ssh_config["username"])

        commands: list[str] = [
            "sudo apt-get update -y",
            "sudo apt-get install -y git",
            "sudo apt-get install -y python3.11 pip",
            "sudo apt install -y python3.11-venv",
            "sudo mkdir /var/www/",
            "sudo chmod 777 /var/www/",
            "git config --global credential.helper store",
            f"echo https://{self.json_github_config['token']}:x-oauth-basic@github.com > ~/.git-credentials",
            "git clone https://github.com/dtorrejon/networkmanager-tenant.git /var/www/networkmanager-tenant/",
            "sudo chmod 777 -R /var/www/",
            f"echo '@reboot /var/www/networkmanager-tenant/run_server.sh' | crontab -",
            "pip3 install --upgrade pip",
            f"python3.11 -m venv /var/www/networkmanager-tenant/tenant &&"
            f" source /var/www/networkmanager-tenant/tenant/bin/activate &&"
            f" pip install -r /var/www/networkmanager-tenant/requirements.txt",
            "sudo apt-get update -y"]

        response_commands = self.ssh.send_cmd(commands)
        self.ssh.parse_to_str()

        with open(f"{FilePath.get_path(__file__)}/../../../config_files/config_db.yaml", "r") as file:
            config_file = yaml.safe_load(file)

        with open(f"{FilePath.get_path(__file__)}/../../../config_files/config_db.yaml", "w") as file:
            config_file["db_connection"]["database"] = server_name
            yaml.safe_dump(config_file, file)

        self.ssh.put(f"{FilePath.get_path(__file__)}/../../../config_files/config_db.yaml",
                     f"/var/www/networkmanager-tenant/tenant/infraestructure/adapters/repositories/config/config_db.yaml")

        self.google_cloud.reboot()
        return {"vm": response_create_vm.json(),
                "cmds": [response_commands]}

    @staticmethod
    def load_config_file(path: str):
        with open(path, "r", encoding="utf-8") as file:
            payload = json.load(file)
            file.close()
        return payload


if __name__ == '__main__':
    g = GoogleCloudVM()
    g.deploy("tenant-00")
